/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package app;

import java.awt.BorderLayout;
import java.util.Vector;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.WindowConstants;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableColumn;

/**
 * DeviceInfoWindow
 * 
 * Class for representing the device info window
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class DeviceInfoWindow extends JFrame {
	private static final long serialVersionUID = -6849109948331066711L;
	private JTable tblDevices;
	private JPanel panel;
	private JScrollPane scrScroll;
	
	/**
	 * Constructor
	 * 
	 * @param posX X position to appear
	 * @param posY Y position to appear
	 */
	public DeviceInfoWindow(int posX, int posY) {
		initComponents();
		setLocation(posX, posY);
		setSize(400, 300);
	}
	
	/**
	 * Method for initializing the components
	 */
	private void initComponents() {
		panel = new JPanel();
		tblDevices = new JTable();
		scrScroll = new JScrollPane();
		
		// this
		setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		setTitle("SESim Device Window");
		setName("SESimDeviceWindow");
		setResizable(false);
	
		tblDevices.setModel(new DefaultTableModel(	// ugly designer generated code
				new Object[][]{}, new String[]{"Device", "Value"})
				{
					private static final long serialVersionUID = 7384044339739974665L;
					Class[] types = new Class [] { String.class, String.class };
					boolean[] canEdit = new boolean [] { false, false };

					public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
					public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
				}
		);
		scrScroll.setViewportView(tblDevices);
		
		TableColumn col = tblDevices.getColumnModel().getColumn(0);
		col.setMaxWidth(140);
		col.setPreferredWidth(140);
		
		panel.setLayout(new BorderLayout());
		panel.add(scrScroll);
		this.getContentPane().add(panel);
	}
	
	/**
	 * Method for adding devices to the table
	 * @param devices Vector<String> with the devices to add
	 */
	public void insertDevices(Vector<String> devices) {
		DefaultTableModel dtm = new DefaultTableModel(
				new Object[][]{}, new String[]{"Device", "Value"})
		{
			private static final long serialVersionUID = 7384044339739974665L;
			Class[] types = new Class [] { String.class, String.class };
			boolean[] canEdit = new boolean [] { false, false };

			public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
			public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
		};
		tblDevices.setModel(dtm);
		
		for (int i = 0; i < devices.size(); i++)
			dtm.addRow(new Object[]{devices.elementAt(i), ""});
		
		TableColumn col = tblDevices.getColumnModel().getColumn(0);
	    col.setMaxWidth(140);
	    col.setPreferredWidth(140);
	}
	
	/**
	 * Method for changing the value of a device in the table
	 * @param device String identifier of the device
	 * @param value String value to set
	 */
	public void changeValue(String device, String value) {
		boolean found = false;
		for (int i = 0; i < tblDevices.getModel().getRowCount() && !found; i++) {
			if (tblDevices.getValueAt(i, 0).equals(device)) {
				tblDevices.setValueAt((String)value, i, 1);
				found = true;
			}
		}
	}
	
	/**
	 * Method for removing a value from the table
	 * @param device String identifier of the device to be removed
	 */
	public void removeValue(String device)
	{
		boolean found = false;
		for (int i = 0; i < tblDevices.getModel().getRowCount() && !found; i++) {
			if (tblDevices.getValueAt(i, 0).equals(device)) {
				DefaultTableModel dtm = (DefaultTableModel)tblDevices.getModel();
				dtm.removeRow(i);
				
				found = true;
			}
		}
	}
}
