/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package app;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.swing.GroupLayout;
import javax.swing.LayoutStyle;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.JTextArea;
import javax.swing.JSeparator;
import javax.swing.WindowConstants;
import javax.swing.border.EtchedBorder;
import javax.swing.JPanel;
import javax.xml.bind.JAXBException;

import timer.SEMTask;
import timer.TimerTask;
import upnp.UPnPControlPoint;
import xml.SEMParser;

import lib.AVFileFilter;
import lib.SEMFileFilter;
import lib.ImageClass;
import lib.Painter;
import lib.LightPainter;
import lib.SESimControlPoint;
import lib.VideoPainter;
import java.util.Timer;
import interfaces.DeviceDefinition;

import device.*;

import java.util.Hashtable;
import java.util.Vector;
import java.util.HashMap;

/**
 * SESimGUI
 * 
 * Class which represents the main application GUI
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class SESimGUI extends JFrame implements WindowListener, ActionListener {
	private static final long serialVersionUID = 4331405665414075910L;
	public JTextArea taSEMText;
	public JScrollPane scrScrollSEM;
	private DeviceInfoWindow diw_ = null;
	
	private JLabel lblSEM;
	private JLabel lblSEMFile;
	private JLabel lblAVFile;
	public JTextField tfTime;
	private JLabel lblTimer;
	
	private JTextField txtSEMFile;
	private JTextField txtAVFile;
	
	private JButton btnSEMFile;
	private JButton btnAVFile;
	private JButton btnExit;
	private JButton btnInit;
	private JButton btnStart;
	private JButton btnStop;
	private JButton btnUPnP;
	
	private JSeparator sprSeperator1;
	private JSeparator sprSeperator2;
	
	private JPanel panInnerPanel;
	public LightPainter panLightBackLeft;
	public LightPainter panLightBackMiddle;
	public LightPainter panLightBackRight;
	public LightPainter panLightLeft;
	public LightPainter panLightRight;
	public VideoPainter panVideo;
	public Painter panSoundLeft;
	public Painter panSoundRight;
	public Painter panSoundSub;
	public Painter panFanLeft;
	public Painter panFanRight;
	public Painter panVibrator;
	public Painter panAirConditioner;
	public Painter panWaterSprayer;
	public Painter panPerfumer;
	public Painter panFog;
	
	private Hashtable<String, Device> devices_ = null;
	private Timer timer_ = null;
	private Timer semTimer_ = null;
	private TimerTask timerTask_ = null;
	private SEMTask semTask_ = null;
	private boolean initialized = false;
	
	private String[] upnpFiles = new String[] { null, null };
	
	private String loadSEMPath = null;
	private String loadVideoPath = null;
	
	/**
	 * Constructor
	 * 
	 * @param semFile String with the SEM file to enter at the GUI
	 * @param avFile String with the A/V file to enter at the GUI
	 */
	public SESimGUI(String semFile, String avFile) {
		initComponents();
		setLocation(0, 0);
		setSize(800, 600);//java.awt.Toolkit.getDefaultToolkit().getScreenSize());
		addWindowListener(this);
		devices_ = new Hashtable<String, Device>();
		
		txtSEMFile.setText(semFile);
		txtAVFile.setText(avFile);
		diw_ = new DeviceInfoWindow(this.getX()+this.getWidth(), this.getY());
		initialized = false;
	}

	/**
	 * Method for initializing the components
	 */
	private void initComponents() {
		
		lblSEM = new JLabel();
		lblSEM.setText("SEM messages:");
				
		lblSEMFile = new JLabel();
		lblSEMFile.setText("SEM file:");
		
		lblAVFile = new JLabel();
		lblAVFile.setText("A/V file:");
		
		lblTimer = new JLabel();
		lblTimer.setText("Time:");
		
		tfTime = new JTextField();
		tfTime.setText("00:00:00.0");
		tfTime.setEditable(false);
		
		//scrScroll = new JScrollPane();
		scrScrollSEM = new JScrollPane();
		
		taSEMText = new JTextArea();
		taSEMText.setEnabled(false);
				
		btnSEMFile = new JButton();
		btnSEMFile.setText("...");
		btnSEMFile.setActionCommand("btnSEMFile");
		btnSEMFile.addActionListener(this);
		
		btnAVFile = new JButton();
		btnAVFile.setText("...");
		btnAVFile.setActionCommand("btnAVFile");
		btnAVFile.addActionListener(this);
		
		btnExit = new JButton();
		btnExit.setText("Exit");
		btnExit.setActionCommand("btnExit");
		btnExit.addActionListener(this);
		
		btnInit = new JButton();
		btnInit.setText("Initialize");
		btnInit.setActionCommand("btnInit");
		btnInit.addActionListener(this);
		
		btnStart = new JButton();
		btnStart.setText("Start");
		btnStart.setActionCommand("btnStart");
		btnStart.addActionListener(this);
		
		btnStop = new JButton();
		btnStop.setText("Stop");
		btnStop.setActionCommand("btnStop");
		btnStop.addActionListener(this);
		
		btnUPnP = new JButton();
		btnUPnP.setText("UPnP");
		btnUPnP.setActionCommand("btnUPnP");
		btnUPnP.addActionListener(this);
		
		txtSEMFile = new JTextField();
		txtAVFile = new JTextField();
		
		sprSeperator1 = new JSeparator();
		sprSeperator2 = new JSeparator();
		
		// rose display
		panLightBackLeft = new LightPainter();
		panLightBackLeft.setSize(50,50);
		panLightBackLeft.setBorder(new EtchedBorder());
		
		panLightBackMiddle = new LightPainter();
		panLightBackMiddle.setSize(50,50);
		panLightBackMiddle.setBorder(new EtchedBorder());
		
		panLightBackRight = new LightPainter();
		panLightBackRight.setSize(50,50);
		panLightBackRight.setBorder(new EtchedBorder());
		
		panLightLeft = new LightPainter();
		panLightLeft.setSize(50,50);
		panLightLeft.setBorder(new EtchedBorder());
		
		panLightRight = new LightPainter();
		panLightRight.setSize(50,50);
		panLightRight.setBorder(new EtchedBorder());		
		
		panVideo = new VideoPainter();
		panVideo.setPreferredSize(new Dimension(320,240));
		panVideo.setBounds(0, 0, 320, 240);
		panVideo.setBorder(new EtchedBorder());
		
		panSoundLeft = new Painter();
		panSoundLeft.setSize(50,50);
		panSoundLeft.setBorder(new EtchedBorder());
		
		panSoundRight = new Painter();
		panSoundRight.setSize(50,50);
		panSoundRight.setBorder(new EtchedBorder());
		
		panSoundSub = new Painter();
		panSoundSub.setSize(50,50);
		panSoundSub.setBorder(new EtchedBorder());
		
		panFanLeft = new Painter();
		panFanLeft.setSize(50,50);
		panFanLeft.setBorder(new EtchedBorder());
		
		panFanRight = new Painter();
		panFanRight.setSize(50,50);
		panFanRight.setBorder(new EtchedBorder());
		
		panVibrator = new Painter();
		panVibrator.setSize(50,50);
		panVibrator.setBorder(new EtchedBorder());
		
		panAirConditioner = new Painter();
		panAirConditioner.setSize(50,50);
		panAirConditioner.setBorder(new EtchedBorder());
		
		panWaterSprayer = new Painter();
		panWaterSprayer.setSize(50,50);
		panWaterSprayer.setBorder(new EtchedBorder());
		
		panPerfumer = new Painter();
		panPerfumer.setSize(50,50);
		panPerfumer.setBorder(new EtchedBorder());
		
		panFog = new Painter();
		panFog.setSize(50,50);
		panFog.setBorder(new EtchedBorder());
		
		panInnerPanel = new JPanel();
		panInnerPanel.setPreferredSize(new Dimension(800, 1000));
		panInnerPanel.setBorder(new EtchedBorder());
		
		GroupLayout layoutInner = new GroupLayout(panInnerPanel);
		panInnerPanel.setLayout(layoutInner);
		
		layoutInner.setHorizontalGroup(
			layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGroup(layoutInner.createSequentialGroup()
					.addComponent(panFog)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addGap(80)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addComponent(panLightBackLeft)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addComponent(panLightBackMiddle)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addComponent(panLightBackRight)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addGap(30)
					.addGroup(layoutInner.createParallelGroup()
	                	.addComponent(lblTimer)
	                	.addComponent(tfTime)))
				.addGroup(layoutInner.createSequentialGroup()
					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addGap(50)
						.addComponent(panFanLeft))
					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(panLightLeft)
						.addComponent(panSoundLeft))
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addComponent(panVideo)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(panLightRight)
						.addComponent(panSoundRight))
					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addGap(50)
						.addComponent(panFanRight)))
				.addGroup(layoutInner.createSequentialGroup()
						.addGap(100)
						.addComponent(panVibrator)
						.addGap(100))
				.addGroup(layoutInner.createSequentialGroup()
					.addGap(25)
					.addComponent(panAirConditioner)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addComponent(panWaterSprayer)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addComponent(panPerfumer)
					.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
					.addComponent(panSoundSub)
					.addGap(25)));
		
		layoutInner.setVerticalGroup(
				layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGroup(layoutInner.createSequentialGroup()
					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addGap(5)
						.addComponent(panFog)
						.addComponent(panLightBackLeft)
						.addComponent(panLightBackMiddle)
						.addComponent(panLightBackRight)
						.addGroup(layoutInner.createSequentialGroup()
	               					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
	               						.addGroup(layoutInner.createSequentialGroup()
	               							.addComponent(lblTimer)
				               				.addComponent(tfTime))))
						.addGap(5))
					.addGap(6, 6, 6)
					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addGroup(layoutInner.createSequentialGroup()
							.addGap(50)
							.addComponent(panFanLeft)
							.addGap(50))
						.addGroup(layoutInner.createSequentialGroup()
							.addComponent(panLightLeft)
							.addComponent(panSoundLeft))
						.addComponent(panVideo)
						.addGroup(layoutInner.createSequentialGroup()
							.addComponent(panLightRight)
							.addComponent(panSoundRight))
						.addGroup(layoutInner.createSequentialGroup()
							.addGap(50)
							.addComponent(panFanRight)
							.addGap(50)))
					.addGap(6, 6, 6)
					.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addGap(5)
						.addComponent(panVibrator)
						.addGap(5))
				.addGap(6, 6, 6)
				.addGroup(layoutInner.createParallelGroup(GroupLayout.Alignment.LEADING)
					.addComponent(panAirConditioner)
					.addComponent(panWaterSprayer)
					.addComponent(panPerfumer)
					.addComponent(panSoundSub))));
		
		// this
		setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
		setTitle("SESim");
		setName("SESim");
		setResizable(false);
	
		
		scrScrollSEM.setViewportView(taSEMText);
			
		// layout
		GroupLayout layout = new GroupLayout(getContentPane());
		getContentPane().setLayout(layout);
		
		layout.setHorizontalGroup(
	            layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	            .addGroup(layout.createSequentialGroup()
	                .addContainerGap()
	                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	                	.addGroup(layout.createSequentialGroup()
	                		.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	                			.addGroup(layout.createSequentialGroup()
	                				.addComponent(lblSEMFile)
	                				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(txtSEMFile, GroupLayout.PREFERRED_SIZE, 205, GroupLayout.PREFERRED_SIZE)
	                				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(btnSEMFile))
	                			.addGroup(layout.createSequentialGroup()
	                				.addComponent(lblAVFile)
	                				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(txtAVFile, GroupLayout.PREFERRED_SIZE, 205, GroupLayout.PREFERRED_SIZE)
	                				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(btnAVFile))
	                			.addGroup(layout.createSequentialGroup()
	                				.addComponent(btnInit)
	                				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(btnStart)
	                				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(btnStop)
	                				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(btnUPnP)))
	                		.addGap(6, 6, 6)
	                		.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	                			.addGroup(layout.createSequentialGroup()
	                 				.addComponent(lblSEM, GroupLayout.DEFAULT_SIZE, 205, Short.MAX_VALUE))
	                			.addGroup(layout.createSequentialGroup()
	                 				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
	                				.addComponent(scrScrollSEM, GroupLayout.DEFAULT_SIZE, 205, Short.MAX_VALUE))))
	                	.addComponent(sprSeperator1, GroupLayout.DEFAULT_SIZE, 405, Short.MAX_VALUE)
	                	.addComponent(panInnerPanel)
	                	.addComponent(sprSeperator2, GroupLayout.DEFAULT_SIZE, 405, Short.MAX_VALUE)
	                    .addComponent(btnExit, GroupLayout.Alignment.TRAILING))
	                .addContainerGap())
	        );
		
		layout.setVerticalGroup(
	            layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	            .addGroup(layout.createSequentialGroup()
	                .addContainerGap()
	                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
		                .addGroup(layout.createSequentialGroup()
		                	.addGap(6, 6, 6)
		                	.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	                			.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
	                				.addComponent(txtSEMFile, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
	                				.addComponent(btnSEMFile))
	                			.addComponent(lblSEMFile))
	                		.addGap(6, 6, 6)
	                		.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	               				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
	               					.addComponent(txtAVFile, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
	               					.addComponent(btnAVFile))
	               				.addComponent(lblAVFile))
	               			.addGap(6, 6, 6)
	               			.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
	               				.addComponent(btnInit)
	               				.addComponent(btnStart)
	               				.addComponent(btnStop)
	               				.addComponent(btnUPnP)))
	               		.addGroup(layout.createSequentialGroup()
			                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
			      	             .addComponent(lblSEM))
			                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING)
			            		.addComponent(scrScrollSEM, GroupLayout.PREFERRED_SIZE, 105, GroupLayout.PREFERRED_SIZE))))
	             .addGap(6, 6, 6)
	             .addComponent(sprSeperator1, GroupLayout.DEFAULT_SIZE, 405, Short.MAX_VALUE)
	             .addGap(6, 6, 6)
	             .addComponent(panInnerPanel)
	             .addGap(6, 6, 6)
	             .addComponent(sprSeperator2, GroupLayout.DEFAULT_SIZE, 405, Short.MAX_VALUE)
	             .addGap(6, 6, 6)
	             .addComponent(btnExit)
	             .addGap(6, 6, 6))
	        );
		pack();
	}
		
	/**
	 * Method for handling the window closing operation
	 */
	public void windowClosing(WindowEvent event) {
		if(event.getID() == WindowEvent.WINDOW_CLOSING)
		{
			if(JOptionPane.showConfirmDialog(null, "Are you sure?", "Exit?", JOptionPane.YES_NO_OPTION,
					JOptionPane.QUESTION_MESSAGE) == JOptionPane.YES_OPTION) {
				panVideo.destroyVideo();
				deleteTmpFiles();						
				
				System.exit(0);
			}
		}
	}
		
	/**
	 * Method for handling the window iconify operation
	 */
	public void windowIconified(WindowEvent event) {}
		
	/**
	 * Method for handling the window deiconify operation
	 */
	public void windowDeiconified(WindowEvent event) {}
		
	/**
	 * Method for handling the window deactivation operation
	 */
	public void windowDeactivated(WindowEvent event){}
		
	/**
	 * Method for handling the window activation operation
	 */
	public void windowActivated(WindowEvent event) {}
		
	/**
	 * Method for handling the window open operation
	 */
	public void windowOpened(WindowEvent event) {}
	
	/**
	 * Method for handling the window closed operation
	 */
	public void windowClosed(WindowEvent event) {}
		
	/**
	 * Method for handling the actions performed
	 */
	public void actionPerformed(ActionEvent event) {
		if (event.getActionCommand().equals("btnSEMFile"))
			performSEMFile();
		else if (event.getActionCommand().equals("btnAVFile"))
			performAVFile();
		else if (event.getActionCommand().equals("btnExit")) {
			windowClosing(new WindowEvent(this, WindowEvent.WINDOW_CLOSING));
		}
		else if (event.getActionCommand().equals("btnInit")) {
			videoDestroy();
			performInit();
		}
		else if (event.getActionCommand().equals("btnStart"))
			performStart();
		else if (event.getActionCommand().equals("btnStop"))
			performStop();
		else if (event.getActionCommand().equals("btnUPnP"))
			performUPnP();
	}
	
	/**
	 * Method for handling the UPnP control point
	 */
	private void performUPnP() {
		SESimControlPoint sscp = new SESimControlPoint();
		sscp.start();
		
		UPnPControlPoint controlPoint = new UPnPControlPoint(sscp, this);
		controlPoint.setVisible(true);
		
		sscp.stop();
		
		if (!controlPoint.isCanceled()) {
			deleteTmpFiles();
			upnpFiles = controlPoint.getSelectedFiles();
			
			if (upnpFiles[0] != null && upnpFiles[0].toLowerCase().endsWith(".xml"))
				txtSEMFile.setText(upnpFiles[0]);
			else if (upnpFiles[0] != null)
				txtAVFile.setText(upnpFiles[0]);
			
			if (upnpFiles[1] != null && upnpFiles[1].toLowerCase().endsWith(".xml"))
				txtSEMFile.setText(upnpFiles[1]);
			else if (upnpFiles[1] != null)
				txtAVFile.setText(upnpFiles[1]);
		}
	}
	
	/**
	 * Method for handling the SEM filechooser
	 */
	private void performSEMFile()
	{
		JFileChooser jfc = new JFileChooser(loadSEMPath);
		jfc.setFileFilter(new SEMFileFilter());
		
		if(jfc.showOpenDialog(null) != JFileChooser.APPROVE_OPTION)
			return;
		
		if(jfc.getSelectedFile() != null) {
			txtSEMFile.setText(jfc.getSelectedFile().getPath());
			loadSEMPath = jfc.getCurrentDirectory().toString();
		}
	}
	
	/**
	 * Method for handling the A/V filechooser
	 */
	private void performAVFile()
	{
		JFileChooser jfc = new JFileChooser(loadVideoPath);
		jfc.setFileFilter(new AVFileFilter());
		
		if(jfc.showOpenDialog(null) != JFileChooser.APPROVE_OPTION)
			return;
		
		if(jfc.getSelectedFile() != null) {
			txtAVFile.setText(jfc.getSelectedFile().getPath());
			loadVideoPath = jfc.getCurrentDirectory().toString();
		}
	}
	
	/**
	 * Method for performing the initialization
	 */
	private void performInit() {
		if(txtSEMFile.getText().trim().equals(""))
		{
			JOptionPane.showMessageDialog(null, "You have to enter a SEM file!");
			return;
		}
		else if(txtAVFile.getText().trim().equals(""))
		{
			JOptionPane.showMessageDialog(null, "You have to enter an A/V file!");
			return;
		}
		
		// needed for managing that all timers are canceled 
		// and gui is redrawn correctly!
		if (initialized)
			performStop();
		
		if (timerTask_ != null) {
			timerTask_.cancel();
			timerTask_ = null;
		}
		
		if (semTask_ != null) {
			semTask_.cancel();
			semTask_ = null;
		}
		
		if (timer_ != null) {
			timer_.cancel();
			timer_ = null;
		}
		
		if (semTimer_ != null) {
			semTimer_.cancel();
			semTimer_ = null;
		}
		
		resetAllDevices();
		
		Vector<String> buffer = null;
		
		if (txtSEMFile.getText().toLowerCase().endsWith(".xml")) {
			try {
				SEMParser semParser = new SEMParser();
				buffer = semParser.parse(txtSEMFile.getText());
				
				if (buffer == null)
					buffer = new Vector<String>();
				
				// added because SoundType are removed from SEDL/SEV
				// will maybe be removed in later versions!
				buffer.add("00:00:00.0=" + DeviceDefinition.SOUND + "(activate=true, intensity=100)");
			} catch (JAXBException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		else {
			JOptionPane.showMessageDialog(null, "SEM file is no XML file!");
			return;
		}
		
		devices_.put(DeviceDefinition.FOG, new FogDevice(diw_));
		devices_.put(DeviceDefinition.SOUND, new SoundDevice(diw_));
		devices_.put(DeviceDefinition.WATERSPRAYER, new WaterSprayerDevice(diw_));
		devices_.put(DeviceDefinition.AIRCONDITIONER, new AirConditionerDevice(diw_));
		devices_.put(DeviceDefinition.LIGHT, new LightDevice(diw_));
		devices_.put(DeviceDefinition.VIBRATOR, new VibratorDevice(diw_));
		devices_.put(DeviceDefinition.PERFUMER, new PerfumerDevice(diw_));
		devices_.put(DeviceDefinition.FAN, new FanDevice(diw_));

		// initialize gui
		for (String key : devices_.keySet()) {
			Device dev = devices_.get(key);
			HashMap<String, String> bmp = dev.getBitmaps();
			
			for (String element : bmp.keySet()) {
				BufferedImage image = ImageClass.getBufferedImage(bmp.get(element), this);
				if (element.equals("panLightBackLeft"))
					panLightBackLeft.setImage(image);
				else if (element.equals("panLightBackMiddle"))
					panLightBackMiddle.setImage(image);
				else if (element.equals("panLightBackRight"))
					panLightBackRight.setImage(image);	
				else if (element.equals("panLightLeft")) 
					panLightLeft.setImage(image);		
				else if (element.equals("panLightRight"))
					panLightRight.setImage(image);		
				else if (element.equals("panSoundLeft"))
					panSoundLeft.setImage(image);	
				else if (element.equals("panSoundRight"))
					panSoundRight.setImage(image);		
				else if (element.equals("panSoundSub"))
					panSoundSub.setImage(image);	
				else if (element.equals("panFanLeft"))
					panFanLeft.setImage(image);		
				else if (element.equals("panFanRight"))
					panFanRight.setImage(image);		
				else if (element.equals("panVibrator")) 
					panVibrator.setImage(image);	
				else if (element.equals("panAirConditioner"))
					panAirConditioner.setImage(image);		
				else if (element.equals("panWaterSprayer"))
					panWaterSprayer.setImage(image);	
				else if (element.equals("panPerfumer"))
					panPerfumer.setImage(image);
				else if (element.equals("panFog"))
					panFog.setImage(image);
			}
		}
		
		// initialize video panel
		String mediaFile = txtAVFile.getText();
		panVideo.init(mediaFile);
		
		tfTime.setText("00:00:00");
		taSEMText.setText("");
		
		semTask_ = null;
		timerTask_ = null;
		semTask_ = new SEMTask(buffer, devices_, this);
		timerTask_ = new TimerTask(this);
		
		initialized = true;
	}
	
	/**
	 * Method for performing the start action
	 */
	private void performStart() {
		if (!initialized) {
			JOptionPane.showMessageDialog(null, "You have not initialized the player!");
			return;
		}
		
		createInfoWindow();
		panVideo.start();
		
		if (timer_ == null) {
			timer_ = new Timer();
			timer_.schedule(timerTask_, 0, 100);
		}
		else {
			timerTask_.resume();
		}
		
		// play devices
		if (semTimer_ == null) {
			semTimer_ = new Timer();
			semTimer_.schedule(semTask_, 0, 100);
		}
		else {
			semTask_.resume();
		}
	}
	
	/**
	 * Method for performing the stop action
	 */
	private void performStop() {
		if (!initialized) {
			JOptionPane.showMessageDialog(null, "You have not initialized the player!");
			return;
		}
		
		if (panVideo != null)
			panVideo.stop();
		
		if (timerTask_ != null)
			timerTask_.pause();
		
		if (semTask_ != null)
			semTask_.pause();
	}
	
	/**
	 * Method for destroying the video
	 */
	private void videoDestroy() {
		panVideo.destroyVideo();
		Runtime r = Runtime.getRuntime();
		r.gc();
	}	
	
	/**
	 * Method for creating the DeviceInfoWindow
	 */
	private void createInfoWindow() {		
		// create start entries play devices set new values
		Vector<String> devices = new Vector<String>();
		for (String key : devices_.keySet()) {
			Device dev = devices_.get(key);
			if (dev instanceof FanDevice) {
				devices.add("FanDevice Left");
				devices.add("FanDevice Right");
			}
			else if (dev instanceof SoundDevice) {
				devices.add("SoundDevice Left");
				devices.add("SoundDevice Right");
				devices.add("SoundDevice Sub");				
			}
			else if (dev instanceof LightDevice) {
				devices.add("LightDevice Left");
				devices.add("LightDevice Right");
				devices.add("LightDevice LeftBack");
				devices.add("LightDevice MiddleBack");
				devices.add("LightDevice RightBack");				
			}
			else {
				devices.add(dev.getName());
			}
		}
		
		diw_.insertDevices(devices);		
		diw_.setVisible(true);
	}
	
	/**
	 * Method for resetting all device settings and
	 * clearing the images
	 */
	public void resetAllDevices() {
		for (String key : devices_.keySet()) {
			Device dev = devices_.get(key);
			dev.resetSettings(this);
		}
		
		panLightBackLeft.setImage(null);
		panLightBackMiddle.setImage(null);
		panLightBackRight.setImage(null);	
		panLightLeft.setImage(null);		
		panLightRight.setImage(null);		
		panSoundLeft.setImage(null);	
		panSoundRight.setImage(null);		
		panSoundSub.setImage(null);	
		panFanLeft.setImage(null);		
		panFanRight.setImage(null);		
		panVibrator.setImage(null);	
		panAirConditioner.setImage(null);		
		panWaterSprayer.setImage(null);	
		panPerfumer.setImage(null);
		panFog.setImage(null);
		
		devices_ = new Hashtable<String, Device>();
	}
	
	/**
	 * Method for removing temporary files (used by UPnP)
	 */
	private void deleteTmpFiles() {
		if (upnpFiles[0] != null) {
			File f = new File(upnpFiles[0]);
			f.delete();
			upnpFiles[0] = null;
		}
		
		if (upnpFiles[1] != null) {
			File f = new File(upnpFiles[1]);
			f.delete();
			upnpFiles[1] = null;
		}
	}
}
