/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package app;

import java.io.File;

/**
 * SESimulator
 * 
 * entry point of the application
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class SESimulator {

	/**
	 * Main method
	 * @param args to be used
	 */
	public static void main(String[] args) {
		String semFile = "";
		String avFile = "";
		
		String version = System.getProperty("java.version");
        System.out.println("Your JRE version: " + version);
        char minor = version.charAt(2);
        int pos = version.indexOf("_");
        int update = -1;
       
        if (pos != -1) {
    	   try {
    		   update = Integer.valueOf(version.substring(pos+1));
    	   } catch (NumberFormatException e) { }
        }
       
        if(minor < '6') {
    	   System.out.println("\nYou need at least JRE 1.6.0_17 to run this program!");
    	   return;
        }
        else {
    	   if (minor == '6' && update < 17) {
    		   System.out.println("\nYou need at least JRE 1.6.0_17 to run this program!");
        	   return;
    	   }
        }
		
		if (args.length > 0) {
			if(args[0].equalsIgnoreCase("-H")) {
				printUsage();
				return;
			}
			else {
				if (new File(args[0]).isFile())
					semFile = args[0];
				
				if (args.length > 1) {
					if (new File(args[1]).isFile())
						avFile = args[1];
				}
			}
		}
			
		SESimGUI gui = new SESimGUI(semFile, avFile);
		gui.setVisible(true);
	}
	
	/**
	 * Method for printing the usage
	 */
	public static void printUsage() {
		System.out.println("Usage:");
		System.out.println("SESimulator [<sem> <video>] -H");
		System.out.println("===================================");
		System.out.println("<sem>: control file for devices");
		System.out.println("<video>: video to play");
		System.out.println("-H: this help");
	}
}
