/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package device;

import java.awt.Color;

import javax.swing.border.EtchedBorder;

import lib.SEMDefinitions;

import app.DeviceInfoWindow;
import app.SESimGUI;

/**
 * SoundDevice
 * 
 * Class which represents the sound device
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 * 
 * NOTE: OBSOLETE - not defined in standard but used for better readability (will maybe removed in later versions)
 */
public class SoundDevice extends Device {
	private int volume_ = 0;

	/**
	 * Constructor
	 * @param diw DeviceInfoWindow
	 */
	public SoundDevice(DeviceInfoWindow diw) {
		super(diw);
		setName("SoundDevice");
		
		addBitmap("panSoundLeft", "images/soundleft.gif");
		addBitmap("panSoundRight", "images/soundright.gif");
		addBitmap("panSoundSub", "images/soundsub.gif");
	}
	
	/**
	 * Method for reseting device settings
	 * @param gui SESimGUI
	 */
	public void resetSettings(SESimGUI gui) {
		resetDeviceValues();
		volume_ = 0;
		
		if (gui != null) {
			gui.panSoundLeft.setBorder(new EtchedBorder());
			gui.panSoundRight.setBorder(new EtchedBorder());
			gui.panSoundSub.setBorder(new EtchedBorder());
			gui.panSoundLeft.drawText("");
			gui.panSoundRight.drawText("");
			gui.panSoundSub.drawText("");
			getDeviceInfoWindow().removeValue("SoundDevice Left");
			getDeviceInfoWindow().removeValue("SoundDevice Right");
			getDeviceInfoWindow().removeValue("SoundDevice Sub");
		}
	}

	/**
	 * Method for playing the device
	 * @param settings String[] with device settings
	 * @param gui SESimGUI
	 * @return true if everything ok else false
	 */
	public boolean playDevice(String[] settings, SESimGUI gui) {
		resetSettings(null);
		
		for (int i = 0; i < settings.length; i++) {
			String setting = settings[i].trim();
			String[] parts = setting.split("=");
			if (parts[0].equals(SEMDefinitions.ACTIVATE)) {
				if (parts[1].equals(SEMDefinitions.FALSE)) {
					gui.panSoundLeft.setBorder(new EtchedBorder());
					gui.panSoundRight.setBorder(new EtchedBorder());
					gui.panSoundSub.setBorder(new EtchedBorder());
					setActivate(false);
				}
				else {
					gui.panSoundLeft.setBorder(new EtchedBorder(Color.RED, Color.RED));
					gui.panSoundRight.setBorder(new EtchedBorder(Color.RED, Color.RED));
					gui.panSoundSub.setBorder(new EtchedBorder(Color.RED, Color.RED));
					setActivate(true);
				}
			}
			else if (parts[0].equals("intensity"))
				setVolume(Integer.valueOf(parts[1]));
			else {
				System.out.println("Unknown attribute: " + parts[0]);
				return false;
			}
		}
		
		if (getDeviceInfoWindow() != null) {
			if (isActivate()) {
				getDeviceInfoWindow().changeValue("SoundDevice Left", "vol: " + volume_);
				getDeviceInfoWindow().changeValue("SoundDevice Right", "vol: " + volume_);
				getDeviceInfoWindow().changeValue("SoundDevice Sub", "vol: " + volume_);
			}
			else {
				getDeviceInfoWindow().changeValue("SoundDevice Left", "");
				getDeviceInfoWindow().changeValue("SoundDevice Right", "");
				getDeviceInfoWindow().changeValue("SoundDevice Sub", "");
			}
		}
		
		if (isActivate()) {
			gui.panSoundLeft.drawText(String.valueOf(volume_));
			gui.panSoundRight.drawText(String.valueOf(volume_));
			gui.panSoundSub.drawText(String.valueOf(volume_));
		}
		else if (!isActivate()) {
			gui.panSoundLeft.drawText("");
			gui.panSoundRight.drawText("");
			gui.panSoundSub.drawText("");
		}
				
		return true;
	}
	
	/**
	 * Method for retrieving a string representation
	 * @return String with representation
	 */
	public String toString() {
		return "SoundDevice";
	}

	/**
	 * Retrieves the volume in percent
	 * @return int with the volume
	 */
	public int getVolume() {
		return volume_;
	}

	/**
	 * Sets the volume in percent
	 * @param volume int with the volume
	 */
	public void setVolume(int volume) {
		this.volume_ = volume;
	}
	
	/**
	 * Method for pausing the device
	 */
	public void pause() {
		// nothing to do
	}

	/**
	 * Method for resuming the device
	 */
	public void resume() {
		// nothing to do
	}
}
