/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package io;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.URL;
import java.net.URLConnection;

/**
 * Class for downloading a file from a server
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class Downloader {
	/**
	 * Method for downloading a specific file to a specific path
	 * @param pathToFile file to download
	 * @param pathToStore path to store (incl. filename)
	 * @throws IOException thrown if an IO error occurred
	 */
	public static void download(String pathToFile, String pathToStore) throws IOException {
		//System.out.println(pathToFile + " -- " + pathToStore);
		
		if (pathToFile != null && !pathToFile.trim().equals("") && pathToStore != null &&
				!pathToStore.trim().equals("")) {
			BufferedInputStream bis = null;
		    BufferedOutputStream bos = null;
		    
		    try {
		    	URL url = new URL( pathToFile );
	            URLConnection urlc = url.openConnection();

	            bis = new BufferedInputStream(urlc.getInputStream());
	            bos = new BufferedOutputStream(new FileOutputStream(pathToStore));

	            int i;
	            while ((i = bis.read()) != -1) {
	            	bos.write( i );
		        }
	        }
	        finally {
	        	if (bis != null) {
	        		try {
	        			bis.close();
	                }
		            catch (IOException ioe) {
		                  ioe.printStackTrace();
		            }
	        	}
		            
		        if (bos != null) {
		        	try {
		        		bos.close();
		            }
		            catch (IOException ioe) {
		            	ioe.printStackTrace();
		            }
		         }
	        }
		}
		else {
			System.out.println("Input/Output not available");
		}
	}
}
