/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

import java.awt.Component;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.MediaTracker;
import java.awt.image.BufferedImage;

/**
 * ImageClass
 * 
 * Class for managing the graphics
 * 
 * source: http://javaboutique.internet.com/tutorials/Java2D/page03.html - ImageUtilities.java (adopted!)
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class ImageClass {
	/** Create Image from a file, then turn that into a
	 * BufferedImage.
	 */
	public static BufferedImage getBufferedImage(String imageFile, Component c) {
		Image image = c.getToolkit().getImage(imageFile);
		waitForImage(image, c);
		BufferedImage bufferedImage =
		new BufferedImage(image.getWidth(c), image.getHeight(c), BufferedImage.TYPE_INT_RGB);
		Graphics2D g2d = bufferedImage.createGraphics();
		g2d.drawImage(image, 0, 0, c);
		return(bufferedImage);
	}
	
	/** Take an Image associated with a file, and wait until it is
	 * done loading (just a simple application of MediaTracker).
	 * If you are loading multiple images, don't use this
	 * consecutive times; instead, use the version that takes
	 * an array of images.
	 */
	public static boolean waitForImage(Image image, Component c) {
		MediaTracker tracker = new MediaTracker(c);
		tracker.addImage(image, 0);
		try {
			tracker.waitForAll();
		} catch(InterruptedException ie) {}
		return(!tracker.isErrorAny());
	}
}
