/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import javax.swing.JPanel;

/**
 * Painter
 * 
 * Class for representing a bitmap panel
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class Painter extends JPanel {
	private static final long serialVersionUID = -4118435394104958406L;
	private BufferedImage image_ = null;
	private Rectangle imageRect_ = null;
	private String msg_ = "";
	private String msg2_ = null;
	private String msg3_ = null;
	private int textSize_ = 24;
	
	/**
	 * Constructor
	 */
	public Painter() {
	}
	
	/**
	 * Method for setting an image
	 * @param image BufferedImage to be set
	 */
	public void setImage(BufferedImage image) {
		image_ = image;
		imageRect_ = new Rectangle(this.getHeight(), this.getWidth());
		repaint();
	}
	
	/**
	 * Method for painting the component
	 */
	protected void paintComponent( Graphics g ) { 
		super.paintComponent( g );
		Graphics2D g2d = (Graphics2D)g;
		if (image_ != null) {
			g2d.drawImage(image_, 0, 0, imageRect_.height, imageRect_.width, this );
		}
		g.setColor(java.awt.Color.RED);
		g.setFont(new java.awt.Font("Arial", java.awt.Font.BOLD,textSize_));
	    java.awt.FontMetrics fm = g.getFontMetrics();
	    
	    if (msg2_ == null && msg3_ == null) {
		    int msg_width = fm.stringWidth(msg_);
		    int ascent = fm.getMaxAscent();
		    int descent= fm.getMaxDescent();
		    int msg_x = getSize().width/2 - msg_width/2;
		    int msg_y = getSize().height/2 - descent/2 + ascent/2;
		    g.drawString(msg_, msg_x, msg_y);
	    }
	    else {
	    	int msg_width = fm.stringWidth(msg_);
	    	int msg2_width = fm.stringWidth(msg2_);
	    	int msg3_width = fm.stringWidth(msg3_);
	    	
		    int ascent = fm.getMaxAscent();
		    int descent= fm.getMaxDescent();
		    int msg_x = getSize().width/2 - msg_width/2;
		    int msg2_x = getSize().width/2 - msg2_width/2;
		    int msg3_x = getSize().width/2 - msg3_width/2;
		    int msg_y = getSize().height/2 - descent/2 + ascent/2;
		    g.drawString(msg_, msg_x, msg_y-(msg_y/2));
		    g.drawString(msg2_, msg2_x, msg_y);
		    g.drawString(msg3_, msg3_x, msg_y+(msg_y/2));
	    }
	}
	
	/**
	 * Method for drawing a text
	 * @param text String to be drawn
	 */
	public void drawText(String text)  {
		msg_ = text;
		msg2_ = null;
		msg3_ = null;
		this.repaint();
	}
	
	/**
	 * Method for drawing a text in a special size
	 * @param text String to be drawn
	 * @param textSize size of the text
	 */
	public void drawText(String text, int textSize) {
		msg_ = text;
		msg2_ = null;
		msg3_ = null;
		textSize_ = textSize;
		this.repaint();
	}
	
	/**
	 * Method for drawing three strings (one below the other)
	 * @param text1 String with the first text
	 * @param text2 String with the second text
	 * @param text3 String with the third text
	 */
	public void drawText(String text1, String text2, String text3) {
		msg_ = text1;
		msg2_ = text2;
		msg3_ = text3;
		this.repaint();
	}
	
	/**
	 * Method for drawing three strings (one below the other)
	 * in a special size
	 * @param text1 String with the first text
	 * @param text2 String with the second text
	 * @param text3 String with the third text
	 * @param textSize size of the text
	 */
	public void drawText(String text1, String text2, String text3, int textSize) {
		msg_ = text1;
		msg2_ = text2;
		msg3_ = text3;
		textSize_ = textSize;
		this.repaint();
	}
}
