/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package timer;

import app.SESimGUI;
import device.Device;

import java.text.DecimalFormat;
import java.util.Vector;
import java.util.Hashtable;

/**
 * Timer task for SEM file
 * 
 * manages effects of the device playback
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class SEMTask extends java.util.TimerTask {
	private double timeCounter = -1;
	private double timeCounterStop = -1;
	private Hashtable<String, Device> devices_ = null;
	private Vector<String> semSettings_ = null;
	private SESimGUI gui_ = null;
	
	/**
	 * Constructor
	 * 
	 * @param semSettings vector with SEM settings
	 * @param devices hashtable with all devices
	 * @param gui SESimGUI for output
	 */
	public SEMTask(Vector<String> semSettings, Hashtable<String, Device> devices, SESimGUI gui) {
		devices_ = devices;
		semSettings_ = semSettings;
		gui_ = gui;
	}

	/**
	 * Thread running method
	 */
	public void run() {
		if (timeCounterStop == -1) {
			//timeCounter++;			
			timeCounter = gui_.panVideo.getCurrentVideoTime();
			long hours = 0;
			long minutes = 0;
			//long seconds = (long)timeCounter;
			double seconds = timeCounter;
			minutes = (long)(seconds/60);
			seconds = seconds%60;
			hours = minutes/60;
			minutes = minutes%60;
			
			DecimalFormat df2 = new DecimalFormat("#########0.0");
			String valueSeconds = df2.format(timeCounter);
			valueSeconds = valueSeconds.replace(",", ".");
			timeCounter = new Double(valueSeconds).doubleValue();
			
			valueSeconds = df2.format(seconds);
			valueSeconds = valueSeconds.replace(",", ".");
			seconds = new Double(valueSeconds).doubleValue();
			
			String length = "";
			if (hours < 10)
				length = "0" + hours + ":";
			else
				length = hours + ":";
			
			if (minutes < 10)
				length += "0" + minutes + ":";
			else
				length += minutes + ":";
			
			if (seconds < 10)
				length += "0" + seconds;
			else
				length += seconds;

			for (int i = 0; i < semSettings_.size(); i++) {
				String value = semSettings_.elementAt(i);
				
				// perhaps introduce interval of around +-100 ms for better usage 
				if (value.startsWith(length)) {
					gui_.taSEMText.append(value + "\n");
					javax.swing.JScrollBar jBar = gui_.scrScrollSEM.getVerticalScrollBar();
					jBar.setValue(jBar.getMaximum());
					int pos = value.indexOf("=");
					value = value.substring(pos+1);
					// play device
					pos = value.indexOf("(");
					String device = value.substring(0, pos);
					int posEnd = value.indexOf(")");
					value = value.substring(pos+1, posEnd);					
					String[] settings = value.split(",");
					Device curDev = devices_.get(device);
				
					if (curDev != null) {
						if (!curDev.playDevice(settings, gui_))
							System.out.println("Error during play of device \"" + curDev.getName() + "\" at second \"" +
									timeCounter + "\"");
					}
					
					// shouldn't be but currently no trick playing needed
					semSettings_.remove(i);
					i--;
				}
			}
			
		}
	}
	
	/**
	 * Method for pausing the timer
	 */
	public void pause() {
		timeCounterStop = timeCounter;
		
		if (devices_ != null) {
			for (String key : devices_.keySet()) {
				Device dev = devices_.get(key);
				dev.pause();
			}
		}
	}
	
	/**
	 * Method for resuming the timer
	 */
	public void resume() {
		timeCounter = timeCounterStop;
		timeCounterStop = -1;
		if (devices_ != null) {
			for (String key : devices_.keySet()) {
				Device dev = devices_.get(key);
				dev.resume();
			}
		}
	}
}
