/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package timer;

import java.text.DecimalFormat;

import app.SESimGUI;

/**
 * Timer task for own timer task
 * 
 * defines an own timer task for settings the time in the GUI
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class TimerTask extends java.util.TimerTask {
	private double timeCounter = -1;
	private SESimGUI rsgui_ = null;
	private double timeCounterStop = -1;
	
	/**
	 * Constructor
	 * @param rsgui SESimGUI for output
	 */
	public TimerTask(SESimGUI rsgui) {
		rsgui_ = rsgui;
	}

	/**
	 * Thread running method
	 */
	public void run() {
		if (timeCounterStop == -1) {
			//timeCounter++;
			timeCounter = rsgui_.panVideo.getCurrentVideoTime();
			long hours = 0;
			long minutes = 0;
			double seconds = timeCounter;
			minutes = (long)(seconds/60);
			seconds = seconds%60;
			hours = minutes/60;
			minutes = minutes%60;
			
			DecimalFormat df2 = new DecimalFormat("#########0.0");
			String valueSeconds = df2.format(seconds);
			valueSeconds = valueSeconds.replace(",", ".");
			seconds = new Double(valueSeconds).doubleValue();
			
			String length = "";
			if (hours < 10)
				length = "0" + hours + ":";
			else
				length = hours + ":";
			
			if (minutes < 10)
				length += "0" + minutes + ":";
			else
				length += minutes + ":";
			
			if (seconds < 10)
				length += "0" + seconds;
			else
				length += seconds;
			
			rsgui_.tfTime.setText(length);			
		}
	}
	
	/**
	 * Method for pausing the timer
	 */
	public void pause() {
		timeCounterStop = timeCounter;
	}
	
	/**
	 * Method for resuming the timer
	 */
	public void resume() {
		timeCounter = timeCounterStop;
		timeCounterStop = -1;
	}
}
