/*
 * This file is part of SESim.
 *
 * SESim is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SESim is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SESim.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package upnp;
import io.Downloader;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.io.IOException;
import java.util.Random;
import java.util.Vector;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableColumn;

import lib.ContentTableCellRenderer;
import lib.SESimControlPoint;

import org.cybergarage.upnp.Device;
import javax.swing.GroupLayout;

/**
 * Class which represents a UPnP control point GUI
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class UPnPControlPoint extends JDialog implements MouseListener, ActionListener, KeyListener {
	private static final long serialVersionUID = -5381351384549311165L;
	
	private SESimControlPoint sscp_ = null;
	private JTable tblDevices;
	private JTable tblContents;
	private JTable tblResources;
	private JTable tblSelection;
	private JButton bDownload;
	private JButton bCancel;
	private JPanel selectionPanel;
	private boolean isCanceled = false;
		
	private Device selectedServer = null;
	private String[] selectedFiles = new String[] { null, null};
	
	/**
	 * Constructor
	 * 
	 * @param sscp SESimControlPoint to use
	 * @param owner JFrame which is the owner of this dialog
	 */
	public UPnPControlPoint(SESimControlPoint sscp, JFrame owner) {
		super(owner, true);
		sscp_ = sscp;
		setLocation(100, 100);
		setSize(440,500);
		setTitle("SESim - UPnP Control Point");
		setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
		setResizable(false);
		
		bDownload = new JButton("Download");
		bDownload.setActionCommand("Download");
		bDownload.addActionListener(this);
		
		bCancel = new JButton("Cancel");
		bCancel.setActionCommand("Cancel");
		bCancel.addActionListener(this);
		
		JPanel panel = new JPanel();
		tblDevices = new JTable();
		tblDevices.setName("MediaServers");
		JScrollPane scrScroll = new JScrollPane();
		
		tblDevices.setModel(new DefaultTableModel(
				new Object[][]{}, new String[]{"MediaServer", "Device"})
				{
					private static final long serialVersionUID = 7384044339739974665L;
					Class[] types = new Class [] { String.class, Device.class };
					boolean[] canEdit = new boolean [] { false, false };

					public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
					public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
				}
		);
		
	    tblDevices.setColumnSelectionAllowed(false);
	    tblDevices.setRowSelectionAllowed(true);
	    tblDevices.addMouseListener(this);
	    tblDevices.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		tblDevices.getColumn("Device").setMaxWidth(0);
		tblDevices.getColumn("Device").setMinWidth(0);
	    
		scrScroll.setViewportView(tblDevices);
		
		TableColumn col = tblDevices.getColumnModel().getColumn(0);
		col.setMaxWidth(150);
		col.setMinWidth(150);
		col.setPreferredWidth(150);
		
		panel.setLayout(new BorderLayout());
		panel.setPreferredSize(new java.awt.Dimension(150, 200));
		panel.add(scrScroll);
		
		tblContents = new JTable();
		tblContents.setName("ServerContent");
		JPanel panel2 = new JPanel();
		JScrollPane scrScroll2 = new JScrollPane();
		
		tblContents.setModel(new DefaultTableModel(	// ugly designer generated code
				new Object[][]{}, new String[]{"Content", "UPnPContainer"})
				{
					private static final long serialVersionUID = 7384044339739974665L;
					Class[] types = new Class [] { String.class, UPnPContainer.class };
					boolean[] canEdit = new boolean [] { false, false };

					public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
					public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
				}
		);
		
		tblContents.setColumnSelectionAllowed(false);
		tblContents.setRowSelectionAllowed(true);
		tblContents.addMouseListener(this);
		tblContents.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		tblContents.getColumn("UPnPContainer").setMaxWidth(0);
		tblContents.getColumn("UPnPContainer").setMinWidth(0);
		tblContents.setDefaultRenderer(String.class, new ContentTableCellRenderer());
	    
		scrScroll2.setViewportView(tblContents);
		
		TableColumn col2 = tblContents.getColumnModel().getColumn(0);
		col2.setMaxWidth(250);
		col2.setMinWidth(250);
		col2.setPreferredWidth(250);
		
		panel2.setLayout(new BorderLayout());
		panel2.setPreferredSize(new java.awt.Dimension(250, 200));
		panel2.add(scrScroll2);
		
		tblResources = new JTable();
		tblResources.setName("Resources");
		JPanel panel3 = new JPanel();
		JScrollPane scrScroll3 = new JScrollPane();
		
		tblResources.setModel(new DefaultTableModel(	// ugly designer generated code
				new Object[][]{}, new String[]{"Type", "Path"})
				{
					private static final long serialVersionUID = 7384044339739974665L;
					Class[] types = new Class [] { String.class, String.class };
					boolean[] canEdit = new boolean [] { false, false };

					public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
					public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
				}
		);
		
		tblResources.setColumnSelectionAllowed(false);
		tblResources.setRowSelectionAllowed(true);
		tblResources.addMouseListener(this);
		tblResources.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		scrScroll3.setViewportView(tblResources);
		
		TableColumn col3 = tblResources.getColumnModel().getColumn(0);
		//col3.setMaxWidth(80);
		col3.setMinWidth(80);
		col3.setPreferredWidth(80);
		col3 = tblResources.getColumnModel().getColumn(1);
		//col3.setMaxWidth(330);
		col3.setMinWidth(330);
		col3.setPreferredWidth(330);
		
		panel3.setLayout(new BorderLayout());
		panel3.setPreferredSize(new java.awt.Dimension(410, 150));
		panel3.add(scrScroll3);
		
		tblSelection = new JTable();
		tblSelection.setName("Selection");
		selectionPanel = new JPanel();
		JScrollPane scrScroll4 = new JScrollPane();
		
		tblSelection.setModel(new DefaultTableModel(
				new Object[][]{}, new String[]{ "Type", "Selection" })
				{
					private static final long serialVersionUID = 7384044339739974665L;
					Class[] types = new Class [] { String.class, String.class };
					boolean[] canEdit = new boolean [] { false, false };

					public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
					public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
				}
		);
		
		tblSelection.setColumnSelectionAllowed(false);
		tblSelection.setRowSelectionAllowed(true);
		tblSelection.addMouseListener(this);
		tblSelection.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
		//tblSelection.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
		tblSelection.addKeyListener(this);
		scrScroll4.setViewportView(tblSelection);
		TableColumn col4 = tblSelection.getColumnModel().getColumn(0);
		//col4.setMaxWidth(200);
		col4.setMinWidth(80);
		col4.setPreferredWidth(80);
		col4 = tblSelection.getColumnModel().getColumn(1);
		//col4.setMaxWidth(500);
		col4.setMinWidth(330);
		col4.setPreferredWidth(330);		
		
		selectionPanel.setLayout(new BorderLayout());
		selectionPanel.setPreferredSize(new java.awt.Dimension(410, tblSelection.getRowHeight()*4+1));
		scrScroll4.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
		selectionPanel.add(scrScroll4);
		
		
		GroupLayout layout = new GroupLayout(getContentPane());
		getContentPane().setLayout(layout);
		layout.setHorizontalGroup(
				layout.createParallelGroup(GroupLayout.Alignment.CENTER)
	            .addGroup(layout.createSequentialGroup()
	            	.addGap(10, 10, 10)
	                .addComponent(panel, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
	                .addGap(10, 10, 10)
	                .addComponent(panel2, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
	                .addGap(10, 10, 10))
	            .addGroup(layout.createSequentialGroup()
	            	.addGap(10, 10, 10)
	            	.addComponent(panel3, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
	            	.addGap(10, 10, 10))
	            .addGroup(layout.createSequentialGroup()
    	        	.addGap(10, 10, 10)
    	            .addComponent(selectionPanel, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
	                .addGap(10, 10, 10))
	            .addGroup(layout.createSequentialGroup()
            		.addGap(10, 10, 10)
            		.addComponent(bDownload, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
            		.addGap(10, 10, 10)
    	            .addComponent(bCancel, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
	                .addGap(10, 10, 10)));
		
		layout.setVerticalGroup(
	            layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
	            .addGroup(layout.createSequentialGroup()
	                .addGroup(layout.createSequentialGroup()
	                	.addGap(6, 6, 6)
		              	.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
		              		.addComponent(panel, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
		               		.addComponent(panel2, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE))
		               	.addGap(6, 6, 6)
		               	.addComponent(panel3, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
		               	.addGap(6, 6, 6)
		               	.addComponent(selectionPanel, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
		               	.addGap(6, 6, 6)
			            .addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
		              		.addComponent(bDownload, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE)
		              		.addComponent(bCancel, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE, GroupLayout.PREFERRED_SIZE))))            	
				);
   		
   		fillServerList();
	}
	
	/**
	 * Method for filling the server List
	 */
	private void fillServerList() {
		Runnable run = new Runnable() {
			public void run() {
				// insert new servers to the list and refresh the list every 5 seconds
				while (true) {
					insertMediaServer(sscp_.getServerListAsVector());
					try {
						Thread.sleep(5000);
					} catch (InterruptedException e) { }
				}
			}
		};
		
		new Thread(run).start();
	}
	
	/**
	 * Method for adding MediaServers to the table
	 * @param devices Vector<Device> with the MediaServers to add
	 */
	private void insertMediaServer(Vector<Device> mediaServer) {
		int selection = tblDevices.getSelectedRow();
		DefaultTableModel dtm = new DefaultTableModel(
				new Object[][]{}, new String[]{"MediaServer", "Device"})
		{
			private static final long serialVersionUID = 7384044339739974665L;
			Class[] types = new Class [] { String.class, Device.class };
			boolean[] canEdit = new boolean [] { false, false };

			public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
			public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
		};

		tblDevices.setModel(dtm);
		tblDevices.getColumn("Device").setMaxWidth(0);
		tblDevices.getColumn("Device").setMinWidth(0);

		for (int i = 0; i < mediaServer.size(); i++)
			dtm.addRow(new Object[]{mediaServer.elementAt(i).getFriendlyName(), mediaServer.elementAt(i)});
		
		TableColumn col = tblDevices.getColumnModel().getColumn(0);
	    col.setMaxWidth(150);
	    col.setMinWidth(150);
	    col.setPreferredWidth(150);
	    
	    // reselect the old entry if still existing
	    if (selection > -1 && tblDevices.getRowCount() > selection)
	    	tblDevices.setRowSelectionInterval(selection, selection);
	}
	
	/**
	 * Method for adding content to the table
	 * @param rootContainer UPnPContainer which act as parent
	 */
	private void insertContent(UPnPContainer rootContainer) {
		DefaultTableModel dtm = new DefaultTableModel(
				new Object[][]{}, new String[]{"Content", "UPnPContainer"})
		{
			private static final long serialVersionUID = 7384044339739974665L;
			Class[] types = new Class [] { String.class, Device.class };
			boolean[] canEdit = new boolean [] { false, false };

			public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
			public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
		};

		tblContents.setModel(dtm);
		tblContents.getColumn("UPnPContainer").setMaxWidth(0);
		tblContents.getColumn("UPnPContainer").setMinWidth(0);

		//System.out.println(rootContainer);
		if (rootContainer != null && rootContainer.getType() != UPnPTypes.UPNP_TOP) {
			UPnPContainer upnpC = null;
			if (rootContainer.getParentID() < 0)
				upnpC = new UPnPContainer(UPnPTypes.UPNP_CONTAINER, rootContainer.getParentID(), "");
			else
				upnpC = new UPnPContainer(UPnPTypes.UPNP_TOP, rootContainer.getParentID(), "");
			
			dtm.addRow(new Object[]{"..", upnpC});
			
		}
		
		if (rootContainer != null) {
			for (int i = 0; rootContainer.getSubElements() != null && i < rootContainer.getSubElements().size(); i++)
				dtm.addRow(new Object[]{rootContainer.getSubElements().elementAt(i).getTitle(), rootContainer.getSubElements().elementAt(i)});
		}
		
		TableColumn col = tblContents.getColumnModel().getColumn(0);
	    col.setMaxWidth(250);
	    col.setMinWidth(250);
	    col.setPreferredWidth(250);
	}
	
	/**
	 * Method for adding resources to the table
	 * @param rootContainer UPnPContainer which act as parent
	 */
	private void insertResource(UPnPContainer rootContainer) {
		DefaultTableModel dtm = new DefaultTableModel(
				new Object[][]{}, new String[]{"Type", "Path"})
		{
			private static final long serialVersionUID = 7384044339739974665L;
			Class[] types = new Class [] { String.class, String.class };
			boolean[] canEdit = new boolean [] { false, false };

			public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
			public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
		};

		tblResources.setModel(dtm);

		for (int i = 0; rootContainer.getResources() != null && i < rootContainer.getResources().size(); i++) {
			String entry = rootContainer.getResources().elementAt(i).getValue();
			
			// needing only mimetype: protocalInfo -> *:*:mimeType:*
			String[] split = rootContainer.getResources().elementAt(i).getProtocolInfo().split(":");
			dtm.addRow(new Object[]{split[2], entry});
		}
		
		TableColumn col = tblResources.getColumnModel().getColumn(0);
		col.setMaxWidth(80);
		col.setMinWidth(80);
		col.setPreferredWidth(80);
		col = tblResources.getColumnModel().getColumn(1);
		col.setMaxWidth(330);
		col.setMinWidth(330);
		col.setPreferredWidth(330);
	}
	
	/**
	 * Method for clearing the resource table
	 */
	private void clearResourceTable() {
		DefaultTableModel dtm = new DefaultTableModel(
				new Object[][]{}, new String[]{"Type", "Path"})
		{
			private static final long serialVersionUID = 7384044339739974665L;
			Class[] types = new Class [] { String.class, String.class };
			boolean[] canEdit = new boolean [] { false, false };

			public Class getColumnClass(int columnIndex) { return types [columnIndex]; }
			public boolean isCellEditable(int rowIndex, int columnIndex) { return canEdit [columnIndex]; }
		};

		tblResources.setModel(dtm);
		
		TableColumn col = tblResources.getColumnModel().getColumn(0);
		col.setMaxWidth(80);
		col.setMinWidth(80);
		col.setPreferredWidth(80);
		col = tblResources.getColumnModel().getColumn(1);
		col.setMaxWidth(330);
		col.setMinWidth(330);
		col.setPreferredWidth(330);
	}

	public void mouseClicked(MouseEvent e) { }
	public void mouseEntered(MouseEvent e) { }
	public void mouseExited(MouseEvent e) { }
	public void mousePressed(MouseEvent e) { }

	public void mouseReleased(MouseEvent e) {
		int selection = -1;
		if (e.getComponent() instanceof JTable && ((JTable)e.getSource()).getName().equals("MediaServers")) {
			if ((selection = tblDevices.getSelectedRow()) > -1) {
				// retrieve device content
				selectedServer = (Device)tblDevices.getValueAt(selection, 1);				
				insertContent(sscp_.getServerContentList(selectedServer, 0, null));
			}
		}
		else if (e.getComponent() instanceof JTable && ((JTable)e.getSource()).getName().equals("ServerContent")) {
			if ((selection = tblContents.getSelectedRow()) > -1) {
				UPnPContainer container = (UPnPContainer)tblContents.getValueAt(selection, 1);
				if (container.getId() <= 0) {
					insertContent(sscp_.getServerContentList(selectedServer, container.getId(), container));
					clearResourceTable();
				}
				else {
					//System.out.println("This is a file!");
					insertResource(container);
				}
			}
		}
		else if (e.getComponent() instanceof JTable && ((JTable)e.getSource()).getName().equals("Resources")) {
			if ((selection = tblResources.getSelectedRow()) > -1) {
				addResourceToSelection((String)tblResources.getValueAt(selection, 0), (String)tblResources.getValueAt(selection, 1));
			}
		}
	}
	
	/**
	 * Method for adding a resource to the selection table
	 * @param type String with the mimetype
	 * @param value String with the resource
	 */
	private void addResourceToSelection(String type, String value) {
		boolean found = false;
		int contentLength = 0;
		for (int i = 0; i < tblSelection.getModel().getRowCount() && !found; i++) {
			String entry = (String)tblSelection.getValueAt(i, 1);
			
			if (entry.equals(value))
				found = true;
			else {
				if (contentLength < entry.length())
					contentLength = entry.length();
			}
		}
		
		if (!found) {
			DefaultTableModel dtm = (DefaultTableModel)tblSelection.getModel();
			
			if (tblSelection.getModel().getRowCount() == 2)
				dtm.removeRow(0);		
			
			if (contentLength < value.length())
				contentLength = value.length();
			
			dtm.addRow(new Object[]{ type, value });
			
			//tblSelection.setPreferredSize(new Dimension((int)(contentLength*6.5), tblSelection.getModel().getRowCount()*tblSelection.getRowHeight()));
		}
	}

	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().equals("Download")) {
			boolean foundXML = false;
			boolean foundVID = false;
			// the XML check is a left-over from a project related part
			// this part was removed from SESim a while ago
			for (int i = 0; i < tblSelection.getRowCount() && (!foundXML || !foundVID); i++) {
				String value = (String)tblSelection.getValueAt(i, 0);
				value = value.toLowerCase();
				//System.out.println(value);
				if (value.endsWith(".xml") || value.contains("text") || value.contains("application"))
					foundXML = true;
				else
					foundVID = true;
			}
			
			//if (!foundXML)
			//	JOptionPane.showMessageDialog(null, "A SEM description is missing! Please recheck!");
			//else if (!foundVID)
			if (!foundVID)
				JOptionPane.showMessageDialog(null, "A video is missing! Please recheck!");
			else {
				for (int i = 0; i < tblSelection.getRowCount(); i++) {
					String value = (String)tblSelection.getValueAt(i, 1);
					
					String tempdir = System.getProperty("java.io.tmpdir");
					if ( !(tempdir.endsWith("/") || tempdir.endsWith("\\")) )
					   tempdir = tempdir + System.getProperty("file.separator");

					String file = value;
					int pos = value.lastIndexOf("."); // find extension
					if (pos > -1) {
						file = value.substring(pos);
					}
					
					// build a unique name for the files
					String id = Long.toString(Math.abs(new Random().nextLong()));
										
					try {
						Downloader.download(value, tempdir + id + file); // file looks like: 12345.avi
						//System.out.println(i + " -- " + tempdir + id + file);
						selectedFiles[i] = tempdir + id + file;
					} catch (IOException e1) {
						JOptionPane.showMessageDialog(null, "An error occured during downloading: " + e1.getMessage());
					}
				}
				dispose();
			}
		}
		else if (e.getActionCommand().equals("Cancel")) {
			isCanceled = true;
			dispose();			
		}
	}
	
	/**
	 * Method for retrieving if cancel was hit
	 * @return true if cancel was hit else false
	 */
	public boolean isCanceled() {
		return isCanceled;
	}
	
	/**
	 * Method for retrieving the selected resources
	 * @return String[] with the resources (max. 2 resources)
	 */
	public String[] getSelectedFiles() {
		return selectedFiles;
	}

	public void keyPressed(KeyEvent e) { }
	public void keyTyped(KeyEvent e) { }
	
	public void keyReleased(KeyEvent e) {
		if (e.getComponent() instanceof JTable && ((JTable)e.getSource()).getName().equals("Selection")) {
			if (e.getKeyCode() == KeyEvent.VK_DELETE) {
				int selection = -1;
				if ((selection = tblSelection.getSelectedRow()) > -1) {
					DefaultTableModel dtm = (DefaultTableModel)tblSelection.getModel();
					dtm.removeRow(selection);
					tblSelection.setPreferredSize(new Dimension(tblSelection.getWidth(), tblSelection.getModel().getRowCount()*tblSelection.getRowHeight()));
				}
			}
		}
	}
}
